==> zio-aws-ec2_2.13-5.17.123.1-sources.jar: zio/aws/ec2/model/UnmonitorInstancesResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class UnmonitorInstancesResponse(
    instanceMonitorings: Option[
      Iterable[zio.aws.ec2.model.InstanceMonitoring]
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.UnmonitorInstancesResponse = {
    import UnmonitorInstancesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.UnmonitorInstancesResponse
      .builder()
      .optionallyWith(
        instanceMonitorings.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.instanceMonitorings)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.UnmonitorInstancesResponse.ReadOnly =
    zio.aws.ec2.model.UnmonitorInstancesResponse.wrap(buildAwsValue())
}
object UnmonitorInstancesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.UnmonitorInstancesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.UnmonitorInstancesResponse =
      zio.aws.ec2.model.UnmonitorInstancesResponse(
        instanceMonitorings.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def instanceMonitorings
        : Option[List[zio.aws.ec2.model.InstanceMonitoring.ReadOnly]]
    def getInstanceMonitorings: ZIO[Any, AwsError, List[
      zio.aws.ec2.model.InstanceMonitoring.ReadOnly
    ]] = AwsError.unwrapOptionField("instanceMonitorings", instanceMonitorings)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.UnmonitorInstancesResponse
  ) extends zio.aws.ec2.model.UnmonitorInstancesResponse.ReadOnly {
    override val instanceMonitorings
        : Option[List[zio.aws.ec2.model.InstanceMonitoring.ReadOnly]] = scala
      .Option(impl.instanceMonitorings())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.ec2.model.InstanceMonitoring.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.UnmonitorInstancesResponse
  ): zio.aws.ec2.model.UnmonitorInstancesResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.267.1-sources.jar: zio/aws/ec2/model/UnmonitorInstancesResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class UnmonitorInstancesResponse(
    instanceMonitorings: Optional[
      Iterable[zio.aws.ec2.model.InstanceMonitoring]
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.UnmonitorInstancesResponse = {
    import UnmonitorInstancesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.UnmonitorInstancesResponse
      .builder()
      .optionallyWith(
        instanceMonitorings.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.instanceMonitorings)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.UnmonitorInstancesResponse.ReadOnly =
    zio.aws.ec2.model.UnmonitorInstancesResponse.wrap(buildAwsValue())
}
object UnmonitorInstancesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.UnmonitorInstancesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.UnmonitorInstancesResponse =
      zio.aws.ec2.model.UnmonitorInstancesResponse(
        instanceMonitorings.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def instanceMonitorings
        : Optional[List[zio.aws.ec2.model.InstanceMonitoring.ReadOnly]]
    def getInstanceMonitorings: ZIO[Any, AwsError, List[
      zio.aws.ec2.model.InstanceMonitoring.ReadOnly
    ]] = AwsError.unwrapOptionField("instanceMonitorings", instanceMonitorings)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.UnmonitorInstancesResponse
  ) extends zio.aws.ec2.model.UnmonitorInstancesResponse.ReadOnly {
    override val instanceMonitorings
        : Optional[List[zio.aws.ec2.model.InstanceMonitoring.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.instanceMonitorings())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.InstanceMonitoring.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.UnmonitorInstancesResponse
  ): zio.aws.ec2.model.UnmonitorInstancesResponse.ReadOnly = new Wrapper(impl)
}
